==> react-form-builder-5.15.0.tgz: package/lib/index.js <==
import _extends from "@babel/runtime/helpers/esm/extends";
import _asyncToGenerator from "@babel/runtime/helpers/esm/asyncToGenerator";
import _regeneratorRuntime from "@babel/runtime/regenerator";
import { useCallback, useEffect, useRef, useState } from 'react';
import PropTypes from 'prop-types';
import { inputSizes as fieldSizes } from '@s-ui/react-atom-input';
import AtomSpinner, { atomSpinnerTypes } from '@s-ui/react-atom-spinner';
import { getUpdatedFormState } from './mapper/formState';
import { RULES } from './reducer/constants';
import { changeFieldById, fieldsNamesInOrderOfDefinition, fieldsToObject, fieldsToObjectNativeTypes, pickFieldById } from './reducer/fields';
import { json } from './prop-types';
import ProxyField from './ProxyField';
import { reducer } from './reducer';
import { jsx as _jsx } from "react/jsx-runtime";
import { jsxs as _jsxs } from "react/jsx-runtime";
var FormBuilder = function FormBuilder(_ref) {
  var _ref$allowAutoFillOnI = _ref.allowAutoFillOnInitLoad,
    allowAutoFillOnInitLoad = _ref$allowAutoFillOnI === void 0 ? false : _ref$allowAutoFillOnI,
    _ref$allowInitFieldsR = _ref.allowInitFieldsReload,
    allowInitFieldsReload = _ref$allowInitFieldsR === void 0 ? false : _ref$allowInitFieldsR,
    forceRulesOnAllFields = _ref.forceRulesOnAllFields,
    json = _ref.json,
    _ref$initFields = _ref.initFields,
    initFields = _ref$initFields === void 0 ? {} : _ref$initFields,
    _ref$onChange = _ref.onChange,
    onChange = _ref$onChange === void 0 ? function () {} : _ref$onChange,
    _ref$onBlur = _ref.onBlur,
    onBlur = _ref$onBlur === void 0 ? function () {} : _ref$onBlur,
    _ref$onInitFieldsLoad = _ref.onInitFieldsLoadEnd,
    onInitFieldsLoadEnd = _ref$onInitFieldsLoad === void 0 ? function () {} : _ref$onInitFieldsLoad,
    _ref$onFocus = _ref.onFocus,
    onFocus = _ref$onFocus === void 0 ? function () {} : _ref$onFocus,
    _ref$responseIntercep = _ref.responseInterceptor,
    responseInterceptor = _ref$responseIntercep === void 0 ? function (_ref2) {
      var response = _ref2.response;
      return response;
    } : _ref$responseIntercep,
    _ref$requestIntercept = _ref.requestInterceptor,
    requestInterceptor = _ref$requestIntercept === void 0 ? function () {} : _ref$requestIntercept,
    _ref$showSpinnerOnIni = _ref.showSpinnerOnInitLoad,
    showSpinnerOnInitLoad = _ref$showSpinnerOnIni === void 0 ? true : _ref$showSpinnerOnIni,
    loader = _ref.loader,
    fieldSize = _ref.fieldSize,
    _ref$errors = _ref.errors,
    errors = _ref$errors === void 0 ? {} : _ref$errors,
    _ref$alerts = _ref.alerts,
    alerts = _ref$alerts === void 0 ? {} : _ref$alerts,
    _ref$transformations = _ref.transformations,
    transformations = _ref$transformations === void 0 ? function (_, value) {
      return value;
    } : _ref$transformations,
    _ref$baseAPIURL = _ref.baseAPIURL,
    baseAPIURL = _ref$baseAPIURL === void 0 ? 'https://ptaformbuilder-classifiedads.spain.advgo.net' : _ref$baseAPIURL,
    _ref$locale = _ref.locale,
    locale = _ref$locale === void 0 ? 'es-ES' : _ref$locale,
    _ref$useNativeFieldTy = _ref.useNativeFieldType,
    useNativeFieldType = _ref$useNativeFieldTy === void 0 ? false : _ref$useNativeFieldTy,
    _ref$shouldRerenderAl = _ref.shouldRerenderAllFieldsOnChange,
    shouldRerenderAllFieldsOnChange = _ref$shouldRerenderAl === void 0 ? false : _ref$shouldRerenderAl,
    _ref$children = _ref.children,
    renderer = _ref$children === void 0 ? function () {
      return {};
    } : _ref$children;
  var _json$form = json.form,
    _json$form$fields = _json$form.fields,
    fields = _json$form$fields === void 0 ? [] : _json$form$fields,
    _json$form$rules = _json$form.rules,
    rules = _json$form$rules === void 0 ? {} : _json$form$rules,
    formID = _json$form.id;
  var _useState = useState(fields),
    stateFields = _useState[0],
    setStateFields = _useState[1];
  var _useState2 = useState(false),
    stateShowSpinner = _useState2[0],
    setStateShowSpinner = _useState2[1];
  var __PERFORMANCE_UGLY_HACK_STATE_FIELDS__ = useRef();
  __PERFORMANCE_UGLY_HACK_STATE_FIELDS__.current = stateFields;
  var changeField = function changeField(fieldId, fieldValue) {
    var nextFields = changeFieldById(__PERFORMANCE_UGLY_HACK_STATE_FIELDS__.current, fieldId, {
      value: fieldValue
    });
    setStateFields(nextFields);
    return nextFields;
  };
  var handlerChange = useCallback( /*#__PURE__*/function () {
    var _ref3 = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee2(id, value, extraParams, autocompletedField) {
      var reducerWithRules, timerShowSpinner, transformedValue, nextFields, nextStateFields, nextStateFieldsObject, fieldsToUpdate, autocompletedFields;
      return _regeneratorRuntime.wrap(function _callee2$(_context2) {
        while (1) switch (_context2.prev = _context2.next) {
          case 0:
            reducerWithRules = reducer(rules, formID, baseAPIURL, responseInterceptor, requestInterceptor, locale, extraParams);
            timerShowSpinner = setTimeout(function () {
              return setStateShowSpinner(true);
            }, FormBuilder.USER_MINIMAL_DELAY);
            transformedValue = transformations(id, value, pickFieldById(fields, id));
            nextFields = changeField(id, transformedValue);
            clearTimeout(timerShowSpinner);
            _context2.next = 7;
            return reducerWithRules(nextFields, {
              type: RULES,
              id: id
            });
          case 7:
            nextStateFields = _context2.sent;
            clearTimeout(timerShowSpinner);
            setStateFields(nextStateFields);
            nextStateFieldsObject = useNativeFieldType ? fieldsToObjectNativeTypes(nextStateFields) : fieldsToObject(nextStateFields);
            _context2.next = 13;
            return onChange(_extends({}, nextStateFieldsObject, autocompletedField && {
              __AUTOCOMPLETED_FIELD__: autocompletedField
            }, {
              __FIELD_CHANGED__: id,
              __FORM_STATE__: getUpdatedFormState(json.form, nextStateFields)
            }));
          case 13:
            fieldsToUpdate = _context2.sent;
            if (typeof fieldsToUpdate === 'object' && fieldsToUpdate !== null) {
              autocompletedFields = true;
              Object.entries(fieldsToUpdate).forEach( /*#__PURE__*/function () {
                var _ref5 = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee(_ref4) {
                  var key, value;
                  return _regeneratorRuntime.wrap(function _callee$(_context) {
                    while (1) switch (_context.prev = _context.next) {
                      case 0:
                        key = _ref4[0], value = _ref4[1];
                        _context.next = 3;
                        return handlerChange(key, value, undefined, autocompletedFields);
                      case 3:
                      case "end":
                        return _context.stop();
                    }
                  }, _callee);
                }));
                return function (_x5) {
                  return _ref5.apply(this, arguments);
                };
              }());
            }
            setStateShowSpinner(false);
          case 16:
          case "end":
            return _context2.stop();
        }
      }, _callee2);
    }));
    return function (_x, _x2, _x3, _x4) {
      return _ref3.apply(this, arguments);
    };
  }(), // eslint-disable-next-line react-hooks/exhaustive-deps
  [].concat(shouldRerenderAllFieldsOnChange && {
    renderer: renderer
  }));
  useEffect(function () {
    var reducerWithRules = reducer(rules, formID, baseAPIURL, responseInterceptor, requestInterceptor, locale);
    var timerShowSpinner = setTimeout(function () {
      return setStateShowSpinner(showSpinnerOnInitLoad);
    }, FormBuilder.USER_MINIMAL_DELAY);
    fieldsNamesInOrderOfDefinition(fields).reduce( /*#__PURE__*/function () {
      var _ref6 = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee3(previousPromise, fieldId) {
        var _pickFieldById;
        var previousFields, fieldHasNoInitValue, fieldDatalist, fieldCanBeAutocompleted, nextFieldsChanged, nextFieldsWithRules;
        return _regeneratorRuntime.wrap(function _callee3$(_context3) {
          while (1) switch (_context3.prev = _context3.next) {
            case 0:
              _context3.next = 2;
              return previousPromise;
            case 2:
              previousFields = _context3.sent;
              fieldHasNoInitValue = !initFields[fieldId] || initFields[fieldId] === '';
              fieldDatalist = (_pickFieldById = pickFieldById(previousFields, fieldId)) == null ? void 0 : _pickFieldById.datalist;
              fieldCanBeAutocompleted = allowAutoFillOnInitLoad && fieldHasNoInitValue && (fieldDatalist == null ? void 0 : fieldDatalist.length) === 1;
              if (!(!forceRulesOnAllFields && fieldHasNoInitValue && !fieldCanBeAutocompleted)) {
                _context3.next = 8;
                break;
              }
              return _context3.abrupt("return", previousFields);
            case 8:
              nextFieldsChanged = changeField(fieldId, fieldCanBeAutocompleted ? fieldDatalist[0].value : initFields[fieldId]);
              _context3.next = 11;
              return reducerWithRules(nextFieldsChanged, {
                type: RULES,
                id: fieldId
              });
            case 11:
              nextFieldsWithRules = _context3.sent;
              return _context3.abrupt("return", nextFieldsWithRules);
            case 13:
            case "end":
              return _context3.stop();
          }
        }, _callee3);
      }));
      return function (_x6, _x7) {
        return _ref6.apply(this, arguments);
      };
    }(), Promise.resolve(__PERFORMANCE_UGLY_HACK_STATE_FIELDS__.current)).then(function (nextFields) {
      clearTimeout(timerShowSpinner);
      setStateFields(nextFields);
      setStateShowSpinner(false);
      onInitFieldsLoadEnd();
    });
  }, [allowInitFieldsReload ? initFields : null]); // eslint-disable-line

  return /*#__PURE__*/_jsxs("div", {
    className: "sui-FormBuilder",
    children: [stateFields.map(function (field, index) {
      var _field$tabIndex;
      var tabIndex = (_field$tabIndex = field.tabIndex) != null ? _field$tabIndex : index + 1;
      return /*#__PURE__*/_jsx(ProxyField, {
        field: field,
        tabIndex: tabIndex,
        onChange: handlerChange,
        onBlur: onBlur,
        onFocus: onFocus,
        fieldSize: fieldSize,
        errors: errors,
        alerts: alerts,
        renderer: renderer
      }, field.id);
    }), stateShowSpinner && /*#__PURE__*/_jsx(AtomSpinner, {
      type: atomSpinnerTypes.SECTION,
      loader: loader
    })]
  });
};
FormBuilder.USER_MINIMAL_DELAY = 250;
FormBuilder.displayName = 'FormBuilder';
export { fieldSizes as formBuilderFieldSizes };
export { pickFieldById as formBuilderPickFieldById };
export { changeFieldById as formBuilderChangeFieldById };
export { fieldsNamesInOrderOfDefinition as formBuilderFieldsNamesInOrderOfDefinition };
export { checkConstraintsFactory } from './Standard/index.js';
export default FormBuilder;

==> react-form-builder-5.19.0.tgz: package/lib/index.js <==
import _extends from "@babel/runtime/helpers/esm/extends";
import _asyncToGenerator from "@babel/runtime/helpers/esm/asyncToGenerator";
import _regeneratorRuntime from "@babel/runtime/regenerator";
import { useCallback, useEffect, useRef, useState } from 'react';
import PropTypes from 'prop-types';
import { inputSizes as fieldSizes } from '@s-ui/react-atom-input';
import AtomSpinner, { atomSpinnerTypes } from '@s-ui/react-atom-spinner';
import { getUpdatedFormState } from './mapper/formState';
import { RULES } from './reducer/constants';
import { changeFieldById, fieldsNamesInOrderOfDefinition, fieldsToObject, fieldsToObjectNativeTypes, pickFieldById } from './reducer/fields';
import { json } from './prop-types';
import ProxyField from './ProxyField';
import { reducer } from './reducer';
import { jsx as _jsx } from "react/jsx-runtime";
import { jsxs as _jsxs } from "react/jsx-runtime";
var FormBuilder = function FormBuilder(_ref) {
  var _ref$allowAutoFillOnI = _ref.allowAutoFillOnInitLoad,
    allowAutoFillOnInitLoad = _ref$allowAutoFillOnI === void 0 ? false : _ref$allowAutoFillOnI,
    _ref$allowInitFieldsR = _ref.allowInitFieldsReload,
    allowInitFieldsReload = _ref$allowInitFieldsR === void 0 ? false : _ref$allowInitFieldsR,
    forceRulesOnAllFields = _ref.forceRulesOnAllFields,
    json = _ref.json,
    _ref$initFields = _ref.initFields,
    initFields = _ref$initFields === void 0 ? {} : _ref$initFields,
    _ref$onChange = _ref.onChange,
    onChange = _ref$onChange === void 0 ? function () {} : _ref$onChange,
    _ref$onBlur = _ref.onBlur,
    onBlur = _ref$onBlur === void 0 ? function () {} : _ref$onBlur,
    _ref$onInitFieldsLoad = _ref.onInitFieldsLoadEnd,
    onInitFieldsLoadEnd = _ref$onInitFieldsLoad === void 0 ? function () {} : _ref$onInitFieldsLoad,
    _ref$onFocus = _ref.onFocus,
    onFocus = _ref$onFocus === void 0 ? function () {} : _ref$onFocus,
    _ref$responseIntercep = _ref.responseInterceptor,
    responseInterceptor = _ref$responseIntercep === void 0 ? function (_ref2) {
      var response = _ref2.response;
      return response;
    } : _ref$responseIntercep,
    _ref$requestIntercept = _ref.requestInterceptor,
    requestInterceptor = _ref$requestIntercept === void 0 ? function () {} : _ref$requestIntercept,
    _ref$showSpinnerOnIni = _ref.showSpinnerOnInitLoad,
    showSpinnerOnInitLoad = _ref$showSpinnerOnIni === void 0 ? true : _ref$showSpinnerOnIni,
    loader = _ref.loader,
    fieldSize = _ref.fieldSize,
    _ref$errors = _ref.errors,
    errors = _ref$errors === void 0 ? {} : _ref$errors,
    _ref$alerts = _ref.alerts,
    alerts = _ref$alerts === void 0 ? {} : _ref$alerts,
    _ref$transformations = _ref.transformations,
    transformations = _ref$transformations === void 0 ? function (_, value) {
      return value;
    } : _ref$transformations,
    _ref$baseAPIURL = _ref.baseAPIURL,
    baseAPIURL = _ref$baseAPIURL === void 0 ? 'https://ptaformbuilder-classifiedads.spain.advgo.net' : _ref$baseAPIURL,
    _ref$locale = _ref.locale,
    locale = _ref$locale === void 0 ? 'es-ES' : _ref$locale,
    _ref$useNativeFieldTy = _ref.useNativeFieldType,
    useNativeFieldType = _ref$useNativeFieldTy === void 0 ? false : _ref$useNativeFieldTy,
    _ref$shouldRerenderAl = _ref.shouldRerenderAllFieldsOnChange,
    shouldRerenderAllFieldsOnChange = _ref$shouldRerenderAl === void 0 ? false : _ref$shouldRerenderAl,
    _ref$children = _ref.children,
    renderer = _ref$children === void 0 ? function () {
      return {};
    } : _ref$children;
  var _json$form = json.form,
    _json$form$fields = _json$form.fields,
    fields = _json$form$fields === void 0 ? [] : _json$form$fields,
    _json$form$rules = _json$form.rules,
    rules = _json$form$rules === void 0 ? {} : _json$form$rules,
    formID = _json$form.id;
  var _useState = useState(fields),
    stateFields = _useState[0],
    setStateFields = _useState[1];
  var _useState2 = useState(false),
    stateShowSpinner = _useState2[0],
    setStateShowSpinner = _useState2[1];
  var __PERFORMANCE_UGLY_HACK_STATE_FIELDS__ = useRef();
  __PERFORMANCE_UGLY_HACK_STATE_FIELDS__.current = stateFields;
  var changeField = function changeField(fieldId, fieldValue) {
    var nextFields = changeFieldById(__PERFORMANCE_UGLY_HACK_STATE_FIELDS__.current, fieldId, {
      value: fieldValue
    });
    setStateFields(nextFields);
    return nextFields;
  };
  var handlerChange = useCallback( /*#__PURE__*/function () {
    var _ref3 = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee2(id, value, extraParams, autocompletedField) {
      var reducerWithRules, timerShowSpinner, transformedValue, nextFields, nextStateFields, nextStateFieldsObject, fieldsToUpdate, autocompletedFields;
      return _regeneratorRuntime.wrap(function _callee2$(_context2) {
        while (1) switch (_context2.prev = _context2.next) {
          case 0:
            reducerWithRules = reducer(rules, formID, baseAPIURL, responseInterceptor, requestInterceptor, locale, extraParams);
            timerShowSpinner = setTimeout(function () {
              return setStateShowSpinner(true);
            }, FormBuilder.USER_MINIMAL_DELAY);
            transformedValue = transformations(id, value, pickFieldById(fields, id));
            nextFields = changeField(id, transformedValue);
            clearTimeout(timerShowSpinner);
            _context2.next = 7;
            return reducerWithRules(nextFields, {
              type: RULES,
              id: id
            });
          case 7:
            nextStateFields = _context2.sent;
            clearTimeout(timerShowSpinner);
            setStateFields(nextStateFields);
            nextStateFieldsObject = useNativeFieldType ? fieldsToObjectNativeTypes(nextStateFields) : fieldsToObject(nextStateFields);
            _context2.next = 13;
            return onChange(_extends({}, nextStateFieldsObject, autocompletedField && {
              __AUTOCOMPLETED_FIELD__: autocompletedField
            }, {
              __FIELD_CHANGED__: id,
              __FORM_STATE__: getUpdatedFormState(json.form, nextStateFields)
            }));
          case 13:
            fieldsToUpdate = _context2.sent;
            if (typeof fieldsToUpdate === 'object' && fieldsToUpdate !== null) {
              autocompletedFields = true;
              Object.entries(fieldsToUpdate).forEach( /*#__PURE__*/function () {
                var _ref5 = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee(_ref4) {
                  var key, value;
                  return _regeneratorRuntime.wrap(function _callee$(_context) {
                    while (1) switch (_context.prev = _context.next) {
                      case 0:
                        key = _ref4[0], value = _ref4[1];
                        _context.next = 3;
                        return handlerChange(key, value, undefined, autocompletedFields);
                      case 3:
                      case "end":
                        return _context.stop();
                    }
                  }, _callee);
                }));
                return function (_x5) {
                  return _ref5.apply(this, arguments);
                };
              }());
            }
            setStateShowSpinner(false);
          case 16:
          case "end":
            return _context2.stop();
        }
      }, _callee2);
    }));
    return function (_x, _x2, _x3, _x4) {
      return _ref3.apply(this, arguments);
    };
  }(), // eslint-disable-next-line react-hooks/exhaustive-deps
  [].concat(shouldRerenderAllFieldsOnChange && {
    renderer: renderer
  }));
  useEffect(function () {
    var reducerWithRules = reducer(rules, formID, baseAPIURL, responseInterceptor, requestInterceptor, locale);
    var timerShowSpinner = setTimeout(function () {
      return setStateShowSpinner(showSpinnerOnInitLoad);
    }, FormBuilder.USER_MINIMAL_DELAY);
    fieldsNamesInOrderOfDefinition(fields).reduce( /*#__PURE__*/function () {
      var _ref6 = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee3(previousPromise, fieldId) {
        var _pickFieldById;
        var previousFields, fieldHasNoInitValue, fieldDatalist, fieldCanBeAutocompleted, nextFieldsChanged, nextFieldsWithRules;
        return _regeneratorRuntime.wrap(function _callee3$(_context3) {
          while (1) switch (_context3.prev = _context3.next) {
            case 0:
              _context3.next = 2;
              return previousPromise;
            case 2:
              previousFields = _context3.sent;
              fieldHasNoInitValue = !initFields[fieldId] || initFields[fieldId] === '';
              fieldDatalist = (_pickFieldById = pickFieldById(previousFields, fieldId)) == null ? void 0 : _pickFieldById.datalist;
              fieldCanBeAutocompleted = allowAutoFillOnInitLoad && fieldHasNoInitValue && (fieldDatalist == null ? void 0 : fieldDatalist.length) === 1;
              if (!(!forceRulesOnAllFields && fieldHasNoInitValue && !fieldCanBeAutocompleted)) {
                _context3.next = 8;
                break;
              }
              return _context3.abrupt("return", previousFields);
            case 8:
              nextFieldsChanged = changeField(fieldId, fieldCanBeAutocompleted ? fieldDatalist[0].value : initFields[fieldId]);
              _context3.next = 11;
              return reducerWithRules(nextFieldsChanged, {
                type: RULES,
                id: fieldId
              });
            case 11:
              nextFieldsWithRules = _context3.sent;
              return _context3.abrupt("return", nextFieldsWithRules);
            case 13:
            case "end":
              return _context3.stop();
          }
        }, _callee3);
      }));
      return function (_x6, _x7) {
        return _ref6.apply(this, arguments);
      };
    }(), Promise.resolve(__PERFORMANCE_UGLY_HACK_STATE_FIELDS__.current)).then(function (nextFields) {
      clearTimeout(timerShowSpinner);
      setStateFields(nextFields);
      setStateShowSpinner(false);
      var nextStateFieldsObject = useNativeFieldType ? fieldsToObjectNativeTypes(nextFields) : fieldsToObject(nextFields);
      onInitFieldsLoadEnd(_extends({}, nextStateFieldsObject));
    });
  }, [allowInitFieldsReload ? initFields : null]); // eslint-disable-line

  return /*#__PURE__*/_jsxs("div", {
    className: "sui-FormBuilder",
    children: [stateFields.map(function (field, index) {
      var _field$tabIndex;
      var tabIndex = (_field$tabIndex = field.tabIndex) != null ? _field$tabIndex : index + 1;
      return /*#__PURE__*/_jsx(ProxyField, {
        field: field,
        tabIndex: tabIndex,
        onChange: handlerChange,
        onBlur: onBlur,
        onFocus: onFocus,
        fieldSize: fieldSize,
        errors: errors,
        alerts: alerts,
        renderer: renderer
      }, field.id);
    }), stateShowSpinner && /*#__PURE__*/_jsx(AtomSpinner, {
      type: atomSpinnerTypes.SECTION,
      loader: loader
    })]
  });
};
FormBuilder.USER_MINIMAL_DELAY = 250;
FormBuilder.displayName = 'FormBuilder';
export { fieldSizes as formBuilderFieldSizes };
export { pickFieldById as formBuilderPickFieldById };
export { changeFieldById as formBuilderChangeFieldById };
export { fieldsNamesInOrderOfDefinition as formBuilderFieldsNamesInOrderOfDefinition };
export { checkConstraintsFactory } from './Standard/index.js';
export default FormBuilder;
